package
Version:
v0.0.0-...-61e76d4
Opens a new window with list of versions in this module.
Published: Oct 15, 2020
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 10
Opens a new window with list of known importers.
Documentation
¶
type Normalizer interface {
Normalize(record Record, recordIndex int) (map[string]interface{}, error)
}
type Record interface {
Normalized() map[string]interface{}
NormalizedVal(key string) interface{}
SetNormalized(values map[string]interface{})
SetNormalizedValue(key string, value string)
Bytes() []byte
Binary() string
Hex() string
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.